<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2013.2/706770
 */

namespace Application\View\Helper;

use Zend\View\Helper\HeadScript as ZendHeadScript;
use P4\File\File;

class HeadScript extends ZendHeadScript
{
    protected $customAdded = false;

    /**
     * Retrieve string representation
     * Extends parent to add in custom scripts before going to string.
     *
     * @param  string|int   $indent     Amount of whitespaces or string to use for indention
     * @return string       the head script(s)
     */
    public function toString($indent = null)
    {
        // if we haven't already added the custom scripts do so now
        if (!$this->customAdded) {
            $this->customAdded = true;

            // get the base path as we'll need it later
            $services = $this->getView()->getHelperPluginManager()->getServiceLocator();
            $config   = $services->get('config') + array('css' => array());
            $dev      = isset($config['environment']['mode']) && $config['environment']['mode'] == 'development';
            $accept   = isset($_SERVER['HTTP_ACCEPT_ENCODING']) ? $_SERVER['HTTP_ACCEPT_ENCODING'] : '';
            $gz       = strpos($accept, 'gzip') !== false ? 'gz' : '';
            $basePath = $services->get('viewhelpermanager')->get('basePath')->__invoke();

            // first deal with config declared js
            foreach (array_reverse($config['js']) as $key => $value) {
                // if key is a string, its a 'build', use that if we aren't in dev mode and it exists
                if (is_string($key) && !$dev && is_file(BASE_PATH . '/public' . $key . $gz)) {
                    $this->prependFile($basePath . $key . $gz);
                    continue;
                }

                // we're not using a build so add all 'value' js scripts
                $value = array_reverse((array) $value);
                foreach ($value as $script) {
                    $this->prependFile($basePath . $script);
                }
            }

            // find any custom js to be added
            $files = array_merge(
                glob(BASE_PATH . '/public/custom/*.js'),
                glob(BASE_PATH . '/public/custom/*/*.js')
            );

            // sort the files to ensure a predictable order
            natcasesort($files);

            foreach ($files as $file) {
                $custom = substr($file, strlen(BASE_PATH . '/public/'));
                $this->appendFile($basePath . '/' . $custom);
            }
        }

        $user = $services->get('user')->getId();
        if ($user && $config['usercustom']['script']) {
            $script = str_replace('{user}', $user,
                                 $config['usercustom']['script']);
            if (File::exists("/$script")) {
                $this->appendFile($basePath . '/download' .  $script);
            }
        }
        return parent::toString($indent);
    }
}
